# -*- coding: utf-8 -*-

###########################################################################
# Eole NG - 2007
# Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
# Licence CeCill  cf /root/LicenceEole.txt
# eole@ac-dijon.fr
#
# eolepacksvn : librairie d'accès à Subversion
#
###########################################################################

from eolepack import configserver
from eolepack import eolepackdb
from os.path import join
import subprocess, tempfile, traceback, git

clone_dir = configserver.CLONE_DIR

def git_command(args, project):
    try:
        cmdargs = ['/usr/bin/git', '--work-tree', join(clone_dir, project)]
        cmdargs.extend(args)
        gitcmd = subprocess.Popen(cmdargs, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        ret = gitcmd.wait()
        stdoutdata, stderrdata = gitcmd.communicate()
        return ret, stdoutdata, stderrdata
    except:
        traceback.print_exc()
        return None

def git_clone(git_url):
    """ initialisation du repository git """
    clone_dir = tempfile.mktemp()
    try:
        ret, out, err = git_command(('clone', git_url), clone_dir)
        assert ret == 0
        return clone_dir
    except:
        traceback.print_exc()
        return None

def git_branch(project):
    """retourne les branches d'un projet"""
    try:
        repo = git.Repo(join(clone_dir,project))
        branches = repo.branches
        return branches
    except:
        traceback.print_exc()
        return None

def git_commit(msg, project):
    """commit dans le projet git"""
    try:
        ret, out, err = git_command(('commit', '-a', '-m', msg), project)
        assert ret == 0
        return out
    except:
        traceback.print_exc()
        return None

def git_push(git_url, user, password, project):
    """Push des modifications sur le serveur"""
    try:
        pass
    except:
        pass

def git_log(project, limit):
    """ Affichage du log git """
    try:
        repo = git.Repo(join(clone_dir,project))
        commits = repo.log()
        return commits[:limit]
    except:
        traceback.print_exc()
        return None

def git_tag(project):
    """ Affichage du tag git """
    try:
        repo = git.Repo(join(clone_dir,project))
        tags = repo.tags
        return tags
    except:
        traceback.print_exc()
        return None

